﻿using System;
using System.Collections.Generic;
using System.Linq;
using Syncfusion.SfChart.XForms;
using Native = Syncfusion.SfChart.iOS;
using Xamarin.Forms;
using Syncfusion.SfChart.XForms.iOS.Renderers;
using Xamarin.Forms.Platform.iOS;
using CoreGraphics;
using System.Reflection;
using Syncfusion.SfChart.iOS;
using UIKit;
using Foundation;
using System.Collections.ObjectModel;

namespace Chart_GettingStarted.iOS
{
    public class CustomSelectionBehavior: SFChartSelectionBehavior
    {
        public Xamarin.Forms.ListView ListView { get; set; }
        public Syncfusion.SfChart.XForms.SfChart FormsChart { get; set; }

        public CustomSelectionBehavior(Syncfusion.SfChart.XForms.SfChart xFormschart, Xamarin.Forms.ListView listView)
        {
            ListView = listView;
            FormsChart = xFormschart;
        }

        public override void DidDataPointSelect(SFChartSelectionInfo selectionInfo)
        {
            base.DidDataPointSelect(selectionInfo);

            ViewModel chartBindingContext = FormsChart.BindingContext as ViewModel;

            chartBindingContext.GroupedYValues = new ObservableCollection<Model>();

            var segments = selectionInfo.SelectedSeries.Segments;

            if (selectionInfo.SelectedDataPointIndex == -1)
            {
                chartBindingContext.GroupedYValues.Clear();
                return;
            }

            SFPieSegment selectedSegment = segments[selectionInfo.SelectedDataPointIndex] as SFPieSegment;

            if (selectionInfo.SelectedDataPointIndex == segments.Count - 1)
            {
                PropertyInfo dataPointInfo = typeof(SFCircularSeries).GetProperty("GroupedData", BindingFlags.NonPublic | BindingFlags.Instance);
                List<object> groupedDataPoints = dataPointInfo.GetValue(selectionInfo.SelectedSeries, null) as List<object>;

                for (int i = 0; i < groupedDataPoints.Count; i++)
                {
                    chartBindingContext.GroupedYValues.Add(new Model((groupedDataPoints[i] as Model).XValue, (groupedDataPoints[i] as Model).YValue));
                }
            }
            else
            {
                int selectedDataPointIndex = 0;
                var itemsource = selectionInfo.SelectedSeries.ItemsSource;
                foreach (Model item in itemsource)
                {
                    if ((item as Model).YValue == selectedSegment.YValue)
                    {
                        selectedDataPointIndex = (itemsource as ObservableCollection<Model>).IndexOf(item);
                        break;
                    }
                }

                chartBindingContext.GroupedYValues.Add(new Model((itemsource as ObservableCollection<Model>)[selectedDataPointIndex].XValue, selectedSegment.YValue));
            }

            if (ListView != null)
            {
                ListView.ItemsSource = null;
                ListView.ItemsSource = chartBindingContext.GroupedYValues;
            }
        }
    }
}
